==> cloudinary-core-1.5.0-sources.jar: com/cloudinary/transformation/Condition.java <==
package com.cloudinary.transformation;

import com.cloudinary.Transformation;
import com.cloudinary.utils.ObjectUtils;
import com.cloudinary.utils.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Represents a condition for {@link Transformation#ifCondition()}
 */
public class Condition {
    public static final Map OPERATORS = ObjectUtils.asMap(
            "=", "eq",
            "!=", "ne",
            "<", "lt",
            ">", "gt",
            "<=", "lte",
            ">=", "gte",
            "&&", "and",
            "||", "or");

    public static final Map PARAMETERS = ObjectUtils.asMap(
            "width", "w",
            "height", "h",
            "aspect_ratio", "ar",
            "aspectRatio", "ar",
            "page_count", "pc",
            "pageCount", "pc",
            "face_count", "fc",
            "faceCount", "fc"
    );

    protected List<String> predicateList = null;
    private Transformation parent = null;

    public Condition() {
        predicateList = new ArrayList<String>();

    }

    /**
     * Create a Condition Object. The conditionStr string will be translated to a serialized condition.
     *
     * @param conditionStr condition in string format
     */
    public Condition(String conditionStr) {
        this();
        if (conditionStr != null) {
            predicateList.add(literal(conditionStr));
        }
    }

    private String literal(String conditionStr) {

        String replacement;
        conditionStr = conditionStr.replaceAll("[ _]+", "_");
        Pattern replaceRE = Pattern.compile("(" + StringUtils.join(PARAMETERS.keySet(), "|") + "|[=<>&|!]+)");
        Matcher matcher = replaceRE.matcher(conditionStr);
        StringBuffer result = new StringBuffer(conditionStr.length());
        while (matcher.find()) {
            if (OPERATORS.containsKey(matcher.group())) {
                replacement = (String) OPERATORS.get(matcher.group());
            } else if (PARAMETERS.containsKey(matcher.group())) {
                replacement = (String) PARAMETERS.get(matcher.group());
            } else {
                replacement = matcher.group();
            }
            matcher.appendReplacement(result, replacement);
        }
        matcher.appendTail(result);
        return result.toString();
    }

    public Transformation getParent() { return parent;}

    public Condition setParent(Transformation parent) {
        this.parent = parent;
        return this;
    }

    public String serialize() { return StringUtils.join(predicateList, "_");}

    @Override
    public String toString() {
        return serialize();
    }

    protected Condition predicate(String name, String operator, String value) {
        if (OPERATORS.containsKey(operator)) {
            operator = (String) OPERATORS.get(operator);
        }
        predicateList.add(String.format("%s_%s_%s", name, operator, value));
        return this;
    }

    public Condition and() {
        predicateList.add("and");
        return this;
    }

    public Condition or() {
        predicateList.add("or");
        return this;
    }

    /**
     * Terminates the definition of the condition and continue with Transformation definition.
     * @return the Transformation object this Condition is attached to.
     */
    public Transformation then() {
        getParent().ifCondition(serialize());
        return getParent();
    }

    public Condition width(String operator, Object value) {
        predicateList.add("w_" + operator + "_" + value);
        return this;
    }

    public Condition height(String operator, Object value) {
        predicateList.add("h_" + operator + "_" + value);
        return this;
    }

    public Condition aspectRatio(String operator, Object value) {
        predicateList.add("ar_" + operator + "_" + value);
        return this;
    }

    /**
     * @deprecated Use {@link #faceCount(String, Object)} instead
     */
    public Condition faces(String operator, Object value) {
        return faceCount(operator, value);
    }

    public Condition faceCount(String operator, Object value) {
        predicateList.add("fc_" + operator + "_" + value);
        return this;
    }

    /**
     * @deprecated Use {@link #pageCount(String, Object)} instead
     */
    public Condition pages(String operator, Object value) {
        return pageCount(operator, value);
    }

    public Condition pageCount(String operator, Object value) {
        predicateList.add("pc_" + operator + "_" + value);
        return this;
    }
}

==> cloudinary-core-1.22.1-sources.jar: com/cloudinary/transformation/Condition.java <==
package com.cloudinary.transformation;

import com.cloudinary.Transformation;

/**
 * Represents a condition for {@link Transformation#ifCondition()}
 */
public class Condition extends BaseExpression<Condition> {

    public Condition() {
        super();

    }

    /**
     * Create a Condition Object. The conditionStr string will be translated to a serialized condition.
     * <br>
     * For example, <code>new Condition("fc &gt; 3")</code>
     * @param conditionStr condition in string format
     */
    public Condition(String conditionStr) {
        this();
        if (conditionStr != null) {
            expressions.add(normalize(conditionStr));
        }
    }

    @Override
    protected Condition newInstance() {
        return new Condition();
    }

    protected Condition predicate(String name, String operator, Object value) {
        if (OPERATORS.containsKey(operator)) {
            operator = (String) OPERATORS.get(operator);
        }
        expressions.add(String.format("%s_%s_%s", name, operator, value));
        return this;
    }

    /**
     * Terminates the definition of the condition and continue with Transformation definition.
     * @return the Transformation object this Condition is attached to.
     */
    public Transformation then() {
        getParent().ifCondition(serialize());
        return getParent();
    }

    public Condition width(String operator, Object value) {
        return predicate("w", operator, value);
    }

    public Condition height(String operator, Object value) {
        return predicate("h", operator, value);
    }

    public Condition aspectRatio(String operator, Object value) {
        return predicate("ar", operator, value);
    }

    /**
     * @deprecated Use {@link #faceCount(String, Object)} instead
     */
    @Deprecated
    public Condition faces(String operator, Object value) {
        return faceCount(operator, value);
    }

    public Condition faceCount(String operator, Object value) {
        return predicate("fc", operator, value);
    }

    /**
     * @deprecated Use {@link #pageCount(String, Object)} instead
     */
    @Deprecated
    public Condition pages(String operator, Object value) {
        return pageCount(operator, value);
    }

    public Condition pageCount(String operator, Object value) {
        return predicate("pc", operator, value);
    }

}
